WordCountResult class
Result object containing both word count and word array.
Returned by wordsDetect to provide both pieces of information in a single function call.
Example:
WordCountResult result = wordsDetect('Hello World');
print('Found ${result.count} words: ${result.words}');
// Output: Found 2 words: [Hello, World]
Constructors
-
WordCountResult({required List<
String> words, required int count}) -
Creates a new word count result.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited